# Bitmovin Analytics Collector

Instruments adaptive streaming video players and collects information to be sent to the Bitmovin Analytics service. 

To get started collecting data with Bitmovin Analytics you need a License-Key which you can get for free by signing up for a [free Bitmovin account](https://bitmovin.com/dashboard/signup).

## Supported Players

- Bitmovin Web SDK v7
- Bitmovin Web SDK v8
- Shaka
- HLS.js
- DASH.js
- VideoJS
- Native HTMLVideoElement

## Usage

[An interactive getting started guide](https://bitmovin.com/dashboard/getting-started/analytics) on how to integrate Bitmovin Analytics Collector with the Bitmovin Player is available in our Dashboard.

For more comprehensive integration documentation please consult the [Bitmovin Analytics documentation](https://bitmovin.com/docs/analytics/quickstarts).

### Integrating Bitmovin 8

Bitmovin Player v8 comes with Analtyics pre-installed and just requires an `analytics` section containing your license key in the player configuration.

A minimal example:

```js
const configWithAnalytics = {
  key: '<YOUR PLAYER KEY>',
  analytics:   {
    key: '<YOUR ANALYITICS KEY>',
    videoId: 'VIDEO_ID'
  }
};

const container = document.getElementById('my-player');
const player = bitmovin.player.Player(container, configWithAnalytics);
```

To ensure you are running a specific version (e.g. when including the `bitmovin-analytics` package from NPM) override the built-in analytics module:

```js
bitmovin.player.Player.addModule(bitmovin.analytics.PlayerModule);
```

### Integrating 3rd Party Players

To integrate other players pick the appropriate adapter (`HlsAdapter`, `VideojsAdapter`, `ShakaAdapter`, `DashjsAdapter` or `HTMLVideoElementAdapter`) and instantiate the adapter by passing the player instance.

An example for HLS.js:

```js
const analyticsConfig = {
  key: '<YOUR ANALYITICS KEY>',
  videoId: 'VIDEO_ID'
};

const player = new Hls();
const analytics = new bitmovin.analytics.adapters.HlsAdapter(config, player);

player.loadSource('https://path.to/your/stream.m3u8');
player.attachMedia(document.getElementById('video'));
```
